==> vokoscreen_1.9.0.orig.tar.gz: vokoscreen-1.9.0/language/vokoscreen_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Отправить последний видеофайл</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Отправить по эл.почте один или несколько видеофайлов</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Видеофайл будет представлен во вложении</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Выберите один или несколько файлов</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>Без рамки</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Рамка</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>Веб-камера</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>Устройство в настоящее время используется</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Выберите веб-камеру</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Весь экран</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Область экрана</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Лупа</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Кодек</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Не записывать указатель мыши</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Сохранять в папке:</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Проигрыватель</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Сворачивать Vokoscreen во время начала записи </translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Начать</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Время записи</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Размер в КБ</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Размер записываемого экрана</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Настройка частоты</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Обратный отсчёт</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Воспроизвести последний видеофайл</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Отправить видеофайл</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Выберите одно или несколько устройств</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Фактическое кол-во кадров в с.</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>Устройство %1 используется</translation>
    </message>
    <message>
        <source>Your Actual frames in the Settings is too heigh</source>
        <translation>Кол-во фактических кадров в с. превышено</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Перейти</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Рассылка</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Поддержка</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Разработчик</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Кадры</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation>Beta Ubuntu</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Пожертвовать</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Программа для записи</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Переводы</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Исходный код</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Показать значок на верхней панели </translation>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.1.0.orig.tar.gz: vokoscreen-2.1.0/language/vokoscreen_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Устройство в настоящее время используется</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Неизвестно</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Устройство</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Используется</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Отправить последний видеофайл</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Отправить по эл.почте один или несколько видеофайлов</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Видеофайл будет представлен во вложении</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Выберите один или несколько файлов</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Рамка</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Показать в полноэкранном режиме</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Устройство в настоящее время используется</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Устройство</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Используется</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Неизвестно</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Весь экран</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Область экрана</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Лупа</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Кодек</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Не записывать указатель мыши</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Сохранять в папке:</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Проигрыватель</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Сворачивать Vokoscreen во время начала записи </translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Начать</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Отправить</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Время записи</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Размер в КБ</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Размер записываемого экрана</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Настройка частоты</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Обратный отсчёт</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Воспроизвести последний видеофайл</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Отправить видеофайл</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Выберите одно или несколько устройств</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Фактическое кол-во кадров в с.</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Перейти</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Рассылка</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Поддержка</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Разработчик</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Кадры</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Пожертвовать</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Программа для записи</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Переводы</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Исходный код</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Показать значок на верхней панели </translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Доступна новая версия</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Видеокодек</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Звуковой кодек</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Веб-камера</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Выберите веб-камеру</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Зеркалирование</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Экран</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Все экраны</translation>
    </message>
</context>
</TS>
